use axum::{Extension, Json};
use domain::{dto::account::{AuthenticateGooleAccountReq, AuthenticateWithPassword, RefreshToken}, vo::account::{LoginAccount, RefreshTokenResult}};
use library::{cache::account_cache::CacheAccount, resp::response::{ ResData, ResResult}};
use validator::Validate;

pub async fn authenticate_google(
    Json(req): Json<AuthenticateGooleAccountReq>
) -> ResResult<ResData<LoginAccount>> {
    req.validate()?;

    service::account::authenticate_google(req).await
}

pub async fn authenticate_with_password(
    Json(req): Json<AuthenticateWithPassword>
) -> ResResult<ResData<LoginAccount>> {
    req.validate()?;

    service::sys_account::authenticate_with_password(req).await
}

pub async fn refresh_token(
    Extension(account): Extension<CacheAccount>,
    Json(refresh_token): Json<RefreshToken>
) -> ResResult<ResData<RefreshTokenResult>> {
    tracing::debug!("刷新token, {:?}", account);
    service::account::refresh_token(account, refresh_token.token).await
}
