use axum::extract::Query;
use axum::Json;
use validator::Validate;
use domain::dto::feedback::FeedbackAdd;
use domain::dto::pageable::PageParams;
use domain::entities::feedback::Feedback;
use library::resp::pageable::Pageable;
use library::resp::response::{ResData, ResResult};

/// 添加反馈信息
pub async fn add_feedback(
    Json(req): Json<FeedbackAdd>
) -> ResResult<ResData<()>> {
    req.validate()?;

    service::feedback::add_feedback(req).await
}

/// 获取反馈信息列表
pub async fn get_feedback_list_by_page(
    Query(page_params): Query<PageParams>
) -> ResResult<ResData<Pageable<Feedback>>> {
    service::feedback::get_feedback_list_by_page(page_params.page, page_params.page_size).await
}